************************************************************************
************************************************************************
*                 
*   						SAMPLE SELECTION
*
************************************************************************
* people aged 18-34 in wave 1
************************************************************************
* 
* note that you do not need to select this sample if you use the file "sample.dta"
************************************************************************
drop if fs_eta>34

keep fs_eta fsa_6_1a_m fsa_6_1a_m fsa_6_1a_p k3 k4 h12 h3 g3 fs_staciv staciv1 fso_5_2a-fso_5_2h fso_4_3a fso_4_3b fso_4_3c  fso_4_3e           ////
fsa_6_2 fso_5_10a-fso_5_10f fso_1_1p fso_1_1m fs_educ fsfam_5_2 fso_5_12a fso_5_12b fs_staciv regione fso_3_1m fso_3_1f fs_sesso fsa_5_1a



save "C:\Users\TOSIM\Desktop\Age norms[Tosi]\\sample.dta", replace






**************************************************************************
**************************************************************************
*
*                         USING "sample.dta"
*
**************************************************************************
use "C:\Users\TOSIM\Desktop\Age norms[Tosi]\sample.dta"



**************************************************************************
*          
*                 living in the parental home at wave1 (2003)
*
*                     fsa_6_1a_m==1  living with the mother
*                     fsa_6_1a_p==1  living with the father
*  h1=retrospective information (wave 2) about living with parents in wave 1
*
***************************************************************************
 
gen leaving=0 if h1==2
recode leaving (.=0) if fsa_6_1a_m==1 | fsa_6_1a_p==1





************************************************************************
*
*             leaving the parental home between 2003 and 2007
*             H3 k3 k4 = those who do not live with parents in 2007
*
************************************************************************
recode leaving (0=1) if h3!=.
recode leaving (0=1) if k3!=. & k4!=. 







*********************************************************************
*********************************************************************
*    
*                   ROUTES OUT OF THE PARENTAL HOME
*                         marriage VS. other
*
*********************************************************************	
gen route2=leaving
recode route2 (1=2) if h3==2 | g3==2
recode route2 (1=2) if fs_staciv!=2 & staciv1==2

recode route2 (0=0) (1=1 "other routes") (2=2 "marriage"), gen(route)
drop route2





**********************************************************************
**********************************************************************
*
*							AGE NORMS
*
**********************************************************************
*        The "right" age for laeving the parental home
*
*                   fso_3_1f for a female
*                   fso_3_1m for a male
*
**********************************************************************
gen norm=fso_3_1m if fs_sesso==1
replace norm=fso_3_1f if fs_sesso==2
replace norm=fso_3_1m if norm==.
replace norm=fso_3_1f if norm==.


***************************************************************************
*
*   DIFFERENCE BETWEEN THE ACTUAL AGE AND THE RIGHT AGE FOR LEAVING
*
***************************************************************************
gen norm2=fs_eta-norm

recode norm2 (-4/4=0) (.=0 "on time") (5/max=1 "should go") (min/-5=2 "should stay"), gen(norm3)








**************************************************************************************
*
*                        QUALITY OF PARENT-CHILD RELATIONSHIPS
*
**************************************************************************************
*       Children reported (1=never; 5=often) the frequency of disagreements with parents 
*             in 8 areas (helping around the house, spending money, school, free time, )
*             daily organization, work, boyfriend or girlfriend,friends)
*         during the period of co-residence (wave 1, 2003)
*                   SEE WARD ET AL. 2007
****************************************************************************************


recode fso_5_2a- fso_5_2h (5=2.5) (1=5) (4=1) (2=4) (3=2)   , gen(ff_1 ff_2 ff_3 ff_4 ff_5 ff_6 ff_7 ff_8)
recode ff_*(2.5=3)
factor  ff_1- ff_8, pcf mineigen(1) blanks (.4)


*************
*apha
*************
alpha  ff_1-ff_8 , item detail std casewise



**********************************************************************
*
* 				QUALITY OF PARENT-CHILD RELATIONSHIPS
* 			the frequency of disagreement with parents
**********************************************************************
gen quality=ff_1 +ff_2 +ff_3 +ff_4 +ff_5 +ff_6 +ff_7 +ff_8
mean quality
gen quality2=quality
recode quality2(.=17)





*********************************************************************
*
*              TRADITIONAL ATTITUDES TOWARD MARRIAGE/DIVORCE
*
*********************************************************************
recode  fso_4_3a fso_4_3b fso_4_3c  fso_4_3e (.=3), gen(tt_1 tt_2 tt_3 tt_4)
alpha   tt_1 tt_2 tt_3 tt_4, item detail std casewise
gen traditional=fso_4_3a+ fso_4_3b+ fso_4_3c + fso_4_3e

replace traditional=12 if traditional==.





**********************************************************************
*				PARENTS' AND FRIENDS' APPROVAL
*                  
*
*   Q: to what extent would your 
*      mother/father/friends will agree with your decision to leave? 
*      (1=completely agree/ 5=completely disagree)
*
**********************************************************************
recode fso_5_12a (. 6=3), gen(friends)

recode fso_5_12b (. 6=3), gen(mother)
recode fso_5_12b (. 6=3), gen(father)
gen parents=(mother+father)/2 







********************************************************************
*
*            parental divorce or separation
*
********************************************************************
gen divorce_p=fsa_6_2 
recode divorce_p(1 .=0) (2=1)






*********************************************************************
*
*     perceived costs and benefits in leaving the parental home
*
*     the consequences of leaving home for six aspects of young adults' lives: 
*     their level of independence, employment career, sexual relationships,
*     what think the people around them, life satisfaction. 
*      (1= would become much more / 5= would become much less)
*						      alpha= 0.72
*
*********************************************************************
recode fso_5_10a-fso_5_10f (.=3),gen(xx_1 xx_2 xx_3 xx_4 xx_5 xx_6)
 factor xx_1-xx_6, pcf mineigen(1) blanks (.4)
  alpha xx_1 - xx_6 , item detail std casewise
 alpha xx_1 xx_2 xx_4 xx_5 xx_6 , item detail std casewise


 gen improvement=xx_1 +xx_2 +xx_4 +xx_5 +xx_6 

 
 

 
 

 
 
 
 ********************************************************************
 *
 *    						parents education
 *        the higher between mother's and father's degree
 *
 ********************************************************************
 recode fso_1_1p (1 2 3=3) (4 5=2) (6/max=1),gen(educ_f)
 recode fso_1_1m (1 2 3=3) (4 5=2) (6/max=1),gen(educ_m)
 **
gen educ_p2=educ_f if educ_f>=educ_m
replace educ_p2=educ_m if educ_p==.
recode educ_p2(0=2)
 
 recode educ_p2 (3=3 "tertiary") (2=2 "secondary") (1=1 "Lower"), gen(educ_p)
 
 drop educ_p2
 
 
 ********************************************************************
 *                 education
 ********************************************************************
 recode fs_educ (1 2 3=3 "tertiary") (4=2 "secondary") (5/9=1 "lower"), gen(educ)
 
 
 
 
 
 *******************************************************************
 *
 *				household economic conditions
 *
 *******************************************************************
 recode fsfam_5_2 (1=1 "good") (2=2 "adequate") (4=3 "poor") , gen(ec_cond)
 
 


*********************************************************************
*
*               sauthern Italy
*
********************************************************************* 
gen southern=1 if regione==5 | regione==4
recode southern(.=0)

 


*********************************************************************
*                     age in wave 1
*********************************************************************
gen age=fs_eta

*********************************************************************
*                     sex
*********************************************************************
gen sex=fs_sesso




**********************************************************************
*               ADDRESS SAMPLE SELECTION IN WAVE 1
*
*                    inverse mills' ratio
*
**********************************************************************
* coresidence in wave 1
* having at least one child
**********************************************************************
gen coresid=1 if fsa_6_1a_m==1
recode coresid(.=0)

**
gen child=fsa_5_1a
recode child(.=1)


**
probit coresid  c.age##c.age sex southern i.educ_p i.educ child 
*outreg2 using mills.doc, se  bdec(3) rdec(3) sdec(3)  side         ////
*sym(**,*,+) alpha( .01, .05, .1) coefastr ctitle(Coef.)replace
predict event
predict event1, xb
gen imr=normalden(event1)/normal(event1)






**************************************************************************
**************************************************************************
*
*									MODELS
*
*
**************************************************************************
*                             SINGLE DESTINATION
**************************************************************************
*									MODEL 1
**************************************************************************
logit leaving c.age##c.age southern i.educ_p sex i.educ i.ec_cond      ///
i.divorce_p c.improv i.norm3 parents friends imr , robust
margins, dydx(_all) post
*outreg2 using norm.doc, se  bdec(3) rdec(3) sdec(3)  side    ////
*sym(**,*,+) alpha( .01, .05, .1) coefastr ctitle(Coef.)append






********************************************************************************
*
*									MODEL 2: 
*						AGE NORMS X BENEFITS OF LEAVING
*
********************************************************************************
logit leaving c.age##c.age southern i.educ_p sex i.educ i.ec_cond   ///
i.divorce_p c.improv##i.norm3 parents friends imr  , robust
margins, dydx(_all) post
*outreg2 using norm.doc, se  bdec(3) rdec(3) sdec(3)  side    ////
*sym(**,*,+) alpha( .01, .05, .1) coefastr ctitle(Coef.)append


logit leaving c.age##c.age southern i.educ_p sex i.educ i.ec_cond   ///
i.divorce_p c.improv##i.norm3 parents friends imr , robust
margins, at(improv=(10(1)16)) by(norm3) 
marginsplot, level(94) ytitle("") title("") xtitle(Perceived benefits) ci1opt(color(black) lcolor(black) lp(solid))              ///
plot1opts(lc(black) lp(dash_dot) lw(medium) mlc(black) mc(black)) graphregion(color(white)) xscale(r(9.7(0.5)16.3))             ///
ci2opt(color(gs8) lcolor(gs8) lp(solid))plot2opts(lc(gs8) ms(T) lp(solid) lw(medium) mlc(gs8) mc(gs8))                         ///  
ci3opt(color(navy*1) lcolor(navy*1) lp(solid))plot3opts(lc(navy*1) ms(X) lp(longdash) lw(medium) mlc(navy*1) mc(navy*1))  







********************************************************************************
*
*									MODEL 3: 
*						AGE NORMS X PARENTAL APPROVAL
*
********************************************************************************
logit leaving c.age##c.age southern i.educ_p sex i.educ i.ec_cond   ///
i.divorce_p c.improv i.norm3##c.parents friends imr, robust
margins, dydx(_all) post
*outreg2 using norm.doc, se  bdec(3) rdec(3) sdec(3)  side    ////
*sym(**,*,+) alpha( .01, .05, .1) coefastr ctitle(Coef.)append

****
logit leaving c.age##c.age southern i.educ_p sex i.educ i.ec_cond   ///
i.divorce_p c.improv i.norm3##c.parents friends imr, robust
margins, at(parents=(1(1)5)) by(norm3)

marginsplot, ytitle("") title("") xtitle(Parental disapproval) ci1opt(color(black) lcolor(black) lp(solid))                     ///
plot1opts(lc(black) lp(dash_dot) lw(medium) mlc(black) mc(black)) graphregion(color(white)) xscale(r(0.7(0.5)5.3))             ///
ci2opt(color(gs8) lcolor(gs8) lp(solid))plot2opts(lc(gs8) ms(T) lp(solid) lw(medium) mlc(gs8) mc(gs8))                        ///  
ci3opt(color(navy*1) lcolor(navy*1) lp(solid))plot3opts(lc(navy*1) ms(X) lp(longdash) lw(medium) mlc(navy*1) mc(navy*1))







********************************************************************************
*
*									MODEL 4: 
*						QUALITY OF RELATIONSHIPS
*
********************************************************************************
logit leaving c.age##c.age southern i.educ_p sex i.educ i.ec_cond   ///
i.divorce_p c.improv i.norm3 c.parents friends c.quality2##c.quality2 imr, robust
margins, dydx(_all) post
*outreg2 using norm.doc, se  bdec(3) rdec(3) sdec(3)  side    ////
*sym(**,*,+) alpha( .01, .05, .1) coefastr ctitle(Coef.)append

logit leaving c.age##c.age southern i.educ_p sex i.educ i.ec_cond   ///
i.divorce_p c.improv i.norm3 parents friends c.quality2##c.quality2 imr , robust
margins, at(quality2=(9(1)25))
marginsplot, ytitle("") title("") xtitle(Parent-child disagreement) ci1opt(color(black) lcolor(black) lp(solid))          ///
plotopts(lc(black) lp(solid) lw(medium) mlc(black) mc(black)) graphregion(color(white)) xscale(r(8.7(0.5)25.3)) ylabel(0.08(0.02).21) 






***************************************************************************
***************************************************************************
*
*								MEDIATION
*
***************************************************************************
*         Richard Breen, Kristian Bernt Karlson and Anders Holm
*
***************************************************************************
*  Other methods were tested. See:  Kenny, D. A.(2009) Mediation.
*  Retrieved April 23, 2010 from website: http://davidakenny.net/cm/mediate.htm 
*
***************************************************************************

* findit khb
*install khb 


*****************************************************************************
* the role of parents' and friends' disapproval in mediating the association
* between age norms and home-leaving decisions
*****************************************************************************
khb logit leaving i.norm3 || parents friends, concomitant(c.age##c.age southern i.educ_p sex i.educ i.ec_cond   ///
i.divorce_p c.improv    imr) summary disentangle notable, 

 
 


*****************************************************************************
* the role of the quality of parent-child relationships
*****************************************************************************
 khb logit leaving i.norm3 || c.quality2, concomitant(age##age southern i.educ_p sex i.educ i.ec_cond   ///
 i.divorce_p c.improv  parents friends  imr) ape summary, 
 
 

 
 
 
 
 
**************************************************************************
**************************************************************************
*
*					      DOUBLE DESTINATION
*
**************************************************************************
 mlogit route c.age##c.age southern i.educ_p sex i.educ i.ec_cond   ///
 i.divorce_p c.improv i.norm3 parents friends imr c.quality2##c.quality2 traditional
 margins, dydx(_all) pr(outcome(1)) post
*outreg2 using norm_marriage.doc, se  bdec(3) rdec(3) sdec(3)  side    ////
*sym(**,*,+) alpha( .01, .05, .1) coefastr ctitle(Coef.)replace

 
 mlogit route c.fs_eta##c.fs_eta southern i.educ_p sex i.educ i.ec_cond   ///
 i.divorce_p c.improv i.norm3 parents friends imr c.quality2##c.quality2 traditional ,
 margins, dydx(_all) pr(outcome(2)) post
*outreg2 using norm_marriage.doc, se  bdec(3) rdec(3) sdec(3)  side    ////
*sym(**,*,+) alpha( .01, .05, .1) coefastr ctitle(Coef.)append



